.. highlight:: shell

============
Contributing
============

Most of my code I wrote to solve problems I had rather than as general
approaches to problem domains.

That said, I try to write cleanly and generally, and many of the helper
scripts in particular may be useful to others.

Feel free to reach out by email with comments or suggestions.

